==> misfortune-0.1.2.1-136-x86_64.pkg.tar.zst: usr/share/haskell/register/misfortune.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 misfortune
version:              0.1.2.1
visibility:           public
id:                   misfortune-0.1.2.1-15T5Eh0G6CFKM78buKmdp9
key:                  misfortune-0.1.2.1-15T5Eh0G6CFKM78buKmdp9
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/ncfavier/misfortune
synopsis:             fortune-mod clone
description:          fortune-mod clone, in library and executable form.
category:             Console, Game
abi:                  bc48dff90c54207869191f39da89679b
exposed:              True
exposed-modules:      Data.Fortune
hidden-modules:
    Data.Fortune.FortuneFile Data.Fortune.Index Data.Fortune.Stats
    Paths_misfortune

import-dirs:          /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/misfortune
hs-libraries:         HSmisfortune-0.1.2.1-15T5Eh0G6CFKM78buKmdp9
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT directory-1.3.7.1
    filepath-1.4.2.2 knob-0.2.2-HhpH2zzkSI93rWV7pYCvrU
    random-1.2.1.3-BS01zQf871D7daMTFQ0UbO
    random-fu-0.3.0.1-GROOryFSnH97nVi2JXwv7I text-2.0.2
    utf8-string-1.0.2-3k9iW3aOua82FWJzfAeOkO
    vector-0.13.2.0-BnQJYTBpbJKJ2sldbPuyJj

haddock-interfaces:   /usr/share/doc/misfortune/html/misfortune.haddock
haddock-html:         /usr/share/doc/misfortune/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> misfortune-0.1.2.1-137-x86_64.pkg.tar.zst: usr/share/haskell/register/misfortune.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 misfortune
version:              0.1.2.1
visibility:           public
id:                   misfortune-0.1.2.1-LM4hdnDRaKpGy5jWxhpaEy
key:                  misfortune-0.1.2.1-LM4hdnDRaKpGy5jWxhpaEy
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/ncfavier/misfortune
synopsis:             fortune-mod clone
description:          fortune-mod clone, in library and executable form.
category:             Console, Game
abi:                  6646681f1d1a03ae7fb0113c9ee69db0
exposed:              True
exposed-modules:      Data.Fortune
hidden-modules:
    Data.Fortune.FortuneFile Data.Fortune.Index Data.Fortune.Stats
    Paths_misfortune

import-dirs:          /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/misfortune
hs-libraries:         HSmisfortune-0.1.2.1-LM4hdnDRaKpGy5jWxhpaEy
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT directory-1.3.7.1
    filepath-1.4.2.2 knob-0.2.2-HhpH2zzkSI93rWV7pYCvrU
    random-1.2.1.3-FjAccEVuGQcK7S7DSNXHmd
    random-fu-0.3.0.1-GrcSgKwEDK1AZdZy7arWLF text-2.0.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-7jLyylqham1Ij3AknS5IxU

haddock-interfaces:   /usr/share/doc/misfortune/html/misfortune.haddock
haddock-html:         /usr/share/doc/misfortune/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
